@@ -87,6 +87,7 @@ class Weatherbit:
                 "app_temp": row["app_temp"],
                 "rh": row["rh"],
                 "pres": row["pres"],
+                "slp": row["slp"],
                 "clouds": row["clouds"],
                 "solar_rad": row["solar_rad"],
                 "wind_spd": row["wind_spd"],
@@ -138,6 +139,7 @@ class Weatherbit:
                 "app_min_temp": row["app_min_temp"],
                 "rh": row["rh"],
                 "pres": row["pres"],
+                "slp": row["slp"],
                 "clouds": row["clouds"],
                 "wind_spd": row["wind_spd"],
                 "wind_gust_spd": row["wind_gust_spd"],
@@ -247,8 +249,6 @@ class Weatherbit:
     async def async_request(self, method: str, endpoint: str) -> dict:
         """Make a request against the Weatherbit API."""
 
-        _LOGGER.debug(f"ENDPOINT: {BASE_URL}/{endpoint}")
-
         use_running_session = self._session and not self._session.closed
 
         if use_running_session:
